prodiguer-client
================

Client side prodiguer python library.


What is prodiguer-client ?
--------------------------------------

prodiguer-client is a python client library for interacting with prodiguer web services.  It supports pcmdi-metrics management.


Why prodiguer-client ?
--------------------------------------

To simplify & streamline interaction with prodiguer web services.


Who uses prodiguer-client ?
--------------------------------------

IPSL researchers & engineers.


What are the contents of prodiguer-client ?
--------------------------------------

prodiguer_client		Python library.
shell			        Bash scripts.

